// Rhino material definition file for POV-Ray 3.1 and up
//
// Variables you can use in the object material definitions:
// rh_color = object color and transparency
// rh_layercolor = object layer color
// rh_phong = if surface in Rhino has highlight, this is 1, otherwise it is 0
// rh_phong_size = the highlight size, 1 for big highlight and 100 for a small one
// rh_image_map = texture map name. Remember to use PNG format!
// rh_bump_map = bump map name. Remember to use PNG format!


#include "textures.inc"


#declare plastic = material {
texture {
  pigment { rgbf rh_color }
  finish { 
    ambient 1
    diffuse 1
		phong rh_phong
		phong_size rh_phong_size
    }
  }
}


#declare dented_plastic = material {
texture {
  pigment { rgbf rh_color }
  finish { 
    ambient 1
    diffuse 1
		phong rh_phong
		phong_size rh_phong_size
    }
  normal { 
    bumps 1
    scale 0.3
    }
  }
}


#declare shiny = material {
texture {
  pigment { rgbf rh_color }
  finish  {
    ambient 1
    diffuse 1
    specular 1
    roughness 0.05
    reflection 0.4
    }
  }
}

#declare dented_shiny = material {
texture {
  pigment { rgbf rh_color }
  finish  {
    ambient 1
    diffuse 1
		brilliance 0.1
    specular 1
    roughness 0.05
    reflection 0.4
    }
  normal { 
    bumps 1
    scale 0.3
    }
  }
}


#declare shinymetal = material {
texture {
  pigment { rgbf rh_color }
  finish  {
    ambient 1
    diffuse 0.1
    specular 1
    roughness 0.05
    metallic 1
    reflection rh_color
    }
  }
}


#declare dented_shinymetal = material {
texture {
  pigment { rgbf rh_color }
  finish  {
    ambient 1
    diffuse 0.1
    specular 1
    roughness 0.05
    metallic 1
    reflection rh_color
    }
  normal { 
    bumps 1
    scale 0.3
    }
  }
}

#declare rough_shinymetal = material {
texture {
  pigment { rgbf rh_color }
  finish  {
    ambient 1
    diffuse 0.1
    specular 1
    roughness 0.05
    metallic 1
    reflection rh_color
    }
  normal { 
    bumps 0.1
    scale 0.01
    }
  }
}


#declare glass = material {
texture {
  pigment { rgbf rh_color}
  finish  {
    ambient 0.2
    diffuse 0
    specular 1
    roughness 0.05
    reflection 0.4
    }
  }
interior { 
  ior 1.5
  caustics 1
  }
}


#declare textured_shiny = material {
texture {
  pigment { 
		image_map { 
			png rh_image_map
			map_type 1
		}
	}
  finish  {
    ambient 1
    diffuse 1
    specular 1
    roughness 0.05
    reflection 0.4
    }
  }
}


